@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Module Generic - ~/lib/Module/Generic/Hash.pm
-## Version v1.3.0
-## Copyright(c) 2022 DEGUEST Pte. Ltd.
+## Version v1.3.1
+## Copyright(c) 2023 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/03/20
-## Modified 2023/05/06
+## Modified 2023/09/19
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -17,6 +17,7 @@ BEGIN
     use warnings;
     use warnings::register;
     use parent qw( Module::Generic );
+    use vars qw( $KEY_OBJECT );
     use Clone ();
     use Data::Dumper;
     use JSON;
@@ -40,7 +41,9 @@ BEGIN
         'bool'  => sub{$_[0]},
         fallback => 1,
     );
-    our( $VERSION ) = 'v1.3.0';
+    # Do we allow the use of object as hash keys?
+    our $KEY_OBJECT = 0;
+    our( $VERSION ) = 'v1.3.1';
 };
 
 use strict;
@@ -60,6 +63,8 @@ sub new
         disable => ['Module::Generic'],
         debug => 0,
         enable => 0,
+        # Should we allow objects to be used as key? Default to false
+        key_object => $KEY_OBJECT,
     });
     my $self = bless( \%hash => $class );
     $obj->enable(1);
@@ -238,6 +243,17 @@ sub json
     return( Module::Generic::Scalar->new( $json ) );
 }
 
+# Allow hash keys as object
+sub key_object
+{
+    my $self = shift( @_ );
+    if( @_ )
+    {
+        $self->_tie_object->key_object( shift( @_ ) );
+    }
+    return( $self->_tie_object->key_object );
+}
+
 # $h->keys->sort
 sub keys
 {
