@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Module Generic - ~/lib/Module/Generic/TieHash.pm
-## Version v1.2.0
-## Copyright(c) 2022 DEGUEST Pte. Ltd.
+## Version v1.2.1
+## Copyright(c) 2023 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/03/20
-## Modified 2023/09/14
+## Modified 2023/09/19
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -17,7 +17,7 @@ BEGIN
     use warnings::register;
     use warnings;
     use Scalar::Util ();
-    our $VERSION = 'v1.2.0';
+    our $VERSION = 'v1.2.1';
 };
 
 use strict;
@@ -47,6 +47,8 @@ sub TIEHASH
     # Disabled by default so the new() method can access its setup data directly under $self
     # Then new() can call enable to active it
     enable => 1,
+    # Do we enable the use of object as hash key?
+    key_object => $opts->{key_object} // 0,
     # Where to store the actual hash data
     data  => {},
     # object reference address -> value
@@ -79,7 +81,7 @@ sub DELETE
     }
     else
     {
-        if( ref( $key ) )
+        if( ref( $key ) && $self->{key_object} )
         {
             CORE::delete( $repo->{ Scalar::Util::refaddr( $key ) } );
         }
@@ -103,7 +105,7 @@ sub EXISTS
     }
     else
     {
-        if( ref( $key ) )
+        if( ref( $key ) && $self->{key_object} )
         {
             CORE::exists( $repo->{ Scalar::Util::refaddr( $key ) } );
         }
@@ -128,7 +130,7 @@ sub FETCH
     }
     else
     {
-        if( ref( $key ) )
+        if( ref( $key ) && $self->{key_object} )
         {
             return( $repo->{ Scalar::Util::refaddr( $key ) }->[1] );
         }
@@ -215,7 +217,7 @@ sub STORE
         }
         
         #print( STDERR "STORE($caller)[enable=$self->{enable}] <- '$key' -> '$val'\n" );
-        if( ref( $key ) )
+        if( ref( $key ) && $self->{key_object} )
         {
             my $addr = Scalar::Util::refaddr( $key );
             $repo->{ $addr } = [$key, $val];
@@ -235,6 +237,13 @@ sub enable
     return( $self->{enable} );
 }
 
+sub key_object
+{
+    my $self = shift( @_ );
+    $self->{key_object} = shift( @_ ) if( @_ );
+    return( $self->{key_object} );
+}
+
 sub _exclude
 {
     my $self = shift( @_ );
@@ -336,7 +345,7 @@ Module::Generic::TieHash - Generic Tie Hash Mechanism for Object Oriented Hashes
 =head1 SYNOPSIS
 
     use DateTime;
-    my $tie = tie( my %hash, 'Module::Generic::TieHash' );
+    my $tie = tie( my %hash, 'Module::Generic::TieHash', { key_object => 1 } );
     my $now = DateTime->now;
     my $array = [];
     my $ref = {};
@@ -354,13 +363,13 @@ Module::Generic::TieHash - Generic Tie Hash Mechanism for Object Oriented Hashes
 
 =head1 DESCRIPTION
 
-This module implements a tied hash mechanism that accepts as keys strings or references recursively, meaning, even embedded hash references within the top hash reference are also tied to this class.
+This module implements a tied hash mechanism that accepts as keys strings or references, if the option C<key_object> is enabled, recursively, meaning, even embedded hash references within the top hash reference are also tied to this class.
 
 It also supports callback hooks for L<Storable>
 
 =head1 VERSION
 
-    v1.2.0
+    v1.2.1
 
 =head1 AUTHOR
 
